:orphan:



.. _sphx_glr_auto_examples:

.. _general_examples:

General examples
================

Introductory examples.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this plot we perform a sensitivity analysis of the n_bins parameter and we can see how the d...">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_sensitivity_analysis_thumb.png

        :ref:`sphx_glr_auto_examples_plot_sensitivity_analysis.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_sensitivity_analysis

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this plot we can compare the decision regions among a VFI classifier against a CART, a Kerne...">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_vfi_classifier_dicision_boundaries_thumb.png

        :ref:`sphx_glr_auto_examples_plot_vfi_classifier_dicision_boundaries.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_vfi_classifier_dicision_boundaries
.. raw:: html

    <div style='clear:both'></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: auto_examples_python.zip </C:/Users/chris/Storage/work/projects/repos/github/chkoar/vfi/docs/source/auto_examples/auto_examples_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip </C:/Users/chris/Storage/work/projects/repos/github/chkoar/vfi/docs/source/auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
